# -*- coding:utf-8 -*-
from distutils.core import setup
setup(
  name = 'gcmetadata',
  scripts = ['gcmetadata'], 
  version = '0.1',
  description = 'Reads instance/project metadata within a Google Cloud instance',
  author = 'Carlos Peñas',
  author_email = 'carlos.penas@the-cocktail.com',
  url = 'https://github.com/theist/gcmetadata', # use the URL to the github repo
  download_url = 'https://github.com/theist/gcmetadata/tarball/0.1', 
  keywords = ['metadata', 'GCE', 'cloud'],
  classifiers = [],
)

